@@ -49,7 +49,7 @@ struct _GcalMonthCell
   gboolean            hovered : 1;
   gboolean            pressed : 1;
 
-  GcalManager        *manager;
+  GcalContext        *context;
 
   GcalWeatherInfo    *weather_info;
 };
@@ -65,7 +65,7 @@ enum
 enum
 {
   PROP_0,
-  PROP_MANAGER,
+  PROP_CONTEXT,
   N_PROPS
 };
 
@@ -99,7 +99,7 @@ update_style_flags (GcalMonthCell *self)
   today = g_date_time_new_now_local ();
   context = gtk_widget_get_style_context (GTK_WIDGET (self));
 
-  if (datetime_compare_date (self->date, today) == 0)
+  if (gcal_date_time_compare_date (self->date, today) == 0)
     gtk_style_context_add_class (context, "today");
   else
     gtk_style_context_remove_class (context, "today");
@@ -205,6 +205,7 @@ gcal_month_cell_drag_drop (GtkWidget      *widget,
 {
   GcalRecurrenceModType mod;
   GcalMonthCell *self;
+  GcalCalendar *calendar;
   GtkWidget *event_widget;
   GDateTime *start_dt, *end_dt;
   GcalEvent *event;
@@ -225,7 +226,8 @@ gcal_month_cell_drag_drop (GtkWidget      *widget,
     return FALSE;
 
   event = gcal_event_widget_get_event (GCAL_EVENT_WIDGET (event_widget));
-  source = gcal_event_get_source (event);
+  calendar = gcal_event_get_calendar (event);
+  source = gcal_calendar_get_source (calendar);
 
   if (gcal_event_has_recurrence (event) &&
       !ask_recurrence_modification_type (widget, &mod, source))
@@ -271,7 +273,7 @@ gcal_month_cell_drag_drop (GtkWidget      *widget,
           g_clear_pointer (&new_end, g_date_time_unref);
         }
 
-      gcal_manager_update_event (self->manager, event, mod);
+      gcal_manager_update_event (gcal_context_get_manager (self->context), event, mod);
     }
 
   g_clear_pointer (&start_dt, g_date_time_unref);
@@ -347,8 +349,8 @@ gcal_month_cell_finalize (GObject *object)
 {
   GcalMonthCell *self = (GcalMonthCell *)object;
 
-  gcal_clear_datetime (&self->date);
-  g_clear_object (&self->manager);
+  gcal_clear_date_time (&self->date);
+  g_clear_object (&self->context);
 
   G_OBJECT_CLASS (gcal_month_cell_parent_class)->finalize (object);
 }
@@ -364,8 +366,8 @@ gcal_month_cell_set_property (GObject       *object,
 
   switch (property_id)
     {
-    case PROP_MANAGER:
-      gcal_month_cell_set_manager (self, g_value_get_object (value));
+    case PROP_CONTEXT:
+      gcal_month_cell_set_context (self, g_value_get_object (value));
       break;
 
     default:
@@ -384,8 +386,8 @@ gcal_month_cell_get_property (GObject       *object,
 
   switch (property_id)
     {
-    case PROP_MANAGER:
-      g_value_set_object (value, self->manager);
+    case PROP_CONTEXT:
+      g_value_set_object (value, self->context);
       break;
 
     default:
@@ -419,10 +421,10 @@ gcal_month_cell_class_init (GcalMonthCellClass *klass)
                                          1,
                                          GTK_TYPE_WIDGET);
 
-  properties[PROP_MANAGER] = g_param_spec_object ("manager",
-                                                  "Manager",
-                                                  "The GcalManager of the application",
-                                                  GCAL_TYPE_MANAGER,
+  properties[PROP_CONTEXT] = g_param_spec_object ("context",
+                                                  "Context",
+                                                  "The GcalContext of the application",
+                                                  GCAL_TYPE_CONTEXT,
                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, N_PROPS, properties);
@@ -447,8 +449,6 @@ gcal_month_cell_class_init (GcalMonthCellClass *klass)
 static void
 gcal_month_cell_init (GcalMonthCell *self)
 {
-  GcalApplication *application;
-
   gtk_widget_init_template (GTK_WIDGET (self));
 
   /* Setup the month cell as a drag n' drop destination */
@@ -457,18 +457,6 @@ gcal_month_cell_init (GcalMonthCell *self)
                      NULL,
                      0,
                      GDK_ACTION_MOVE);
-
-  /* Connect to the wall clock */
-  application = GCAL_APPLICATION (g_application_get_default ());
-
-  g_assert (application != NULL);
-
-  g_signal_connect_object (gcal_application_get_clock (application),
-                           "day-changed",
-                           G_CALLBACK (day_changed_cb),
-                           self,
-                           0);
-
 }
 
 GtkWidget*
@@ -494,10 +482,10 @@ gcal_month_cell_set_date (GcalMonthCell *self,
 
   g_return_if_fail (GCAL_IS_MONTH_CELL (self));
 
-  if (self->date && date && datetime_compare_date (self->date, date) == 0)
+  if (self->date && date && gcal_date_time_compare_date (self->date, date) == 0)
     return;
 
-  gcal_clear_datetime (&self->date);
+  gcal_clear_date_time (&self->date);
   self->date = g_date_time_ref (date);
 
   /* Day label */
@@ -576,22 +564,30 @@ gcal_month_cell_set_different_month (GcalMonthCell *self,
     gtk_style_context_remove_class (context, "out-of-month");
 }
 
-GcalManager*
-gcal_month_cell_get_manager (GcalMonthCell *self)
+GcalContext*
+gcal_month_cell_get_context (GcalMonthCell *self)
 {
   g_return_val_if_fail (GCAL_IS_MONTH_CELL (self), NULL);
 
-  return self->manager;
+  return self->context;
 }
 
 void
-gcal_month_cell_set_manager (GcalMonthCell *self,
-                             GcalManager   *manager)
+gcal_month_cell_set_context (GcalMonthCell *self,
+                             GcalContext   *context)
 {
   g_return_if_fail (GCAL_IS_MONTH_CELL (self));
 
-  if (g_set_object (&self->manager, manager))
-    g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_MANAGER]);
+  if (!g_set_object (&self->context, context))
+    return;
+
+  g_signal_connect_object (gcal_context_get_clock (context),
+                           "day-changed",
+                           G_CALLBACK (day_changed_cb),
+                           self,
+                           0);
+
+  g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_CONTEXT]);
 }
 
 guint
