@@ -18,6 +18,7 @@
 
 #define G_LOG_DOMAIN "GcalMonthPopover"
 
+#include "gcal-context.h"
 #include "gcal-debug.h"
 #include "gcal-event-widget.h"
 #include "gcal-month-popover.h"
@@ -40,7 +41,7 @@ struct _GcalMonthPopover
   GtkWidget          *relative_to;
   GtkWindow          *transient_for;
 
-  GcalManager        *manager;
+  GcalContext        *context;
 
   DzlAnimation       *opacity_animation;
   DzlAnimation       *position_animation;
@@ -65,7 +66,7 @@ G_DEFINE_TYPE (GcalMonthPopover, gcal_month_popover, GTK_TYPE_WINDOW)
 enum
 {
   PROP_0,
-  PROP_MANAGER,
+  PROP_CONTEXT,
   PROP_RELATIVE_TO,
   PROP_X,
   PROP_Y,
@@ -294,8 +295,8 @@ reposition_popover (GcalMonthPopover *self,
 static void
 update_event_list (GcalMonthPopover *self)
 {
-  g_autofree icaltimetype *start = NULL;
-  g_autofree icaltimetype *end = NULL;
+  g_autoptr (ICalTime) start = NULL;
+  g_autoptr (ICalTime) end = NULL;
   g_autoptr (GDateTime) start_dt = NULL;
   g_autoptr (GDateTime) end_dt = NULL;
   g_autoptr (GList) events = NULL;
@@ -316,10 +317,13 @@ update_event_list (GcalMonthPopover *self)
                                     0, 0, 0);
   end_dt = g_date_time_add_days (start_dt, 1);
 
-  start = datetime_to_icaltime (start_dt);
-  end = datetime_to_icaltime (end_dt);
+  start = gcal_date_time_to_icaltime (start_dt);
+  end = gcal_date_time_to_icaltime (end_dt);
 
-  events = gcal_manager_get_events (self->manager, start, end);
+  events = gcal_manager_get_events (gcal_context_get_manager (self->context), start, end);
+
+  g_clear_object (&start);
+  g_clear_object (&end);
 
   for (l = events; l; l = l->next)
     {
@@ -344,7 +348,7 @@ update_event_list (GcalMonthPopover *self)
 
       event_end = g_date_time_add_days (event_start, 1);
 
-      event_widget = gcal_event_widget_new (event);
+      event_widget = gcal_event_widget_new (self->context, event);
       gcal_event_widget_set_date_start (GCAL_EVENT_WIDGET (event_widget), event_start);
       gcal_event_widget_set_date_end (GCAL_EVENT_WIDGET (event_widget), event_end);
 
@@ -608,8 +612,8 @@ gcal_month_popover_get_property (GObject    *object,
 
   switch (prop_id)
     {
-    case PROP_MANAGER:
-      g_value_set_object (value, self->manager);
+    case PROP_CONTEXT:
+      g_value_set_object (value, self->context);
       break;
 
     case PROP_RELATIVE_TO:
@@ -639,8 +643,8 @@ gcal_month_popover_set_property (GObject      *object,
 
   switch (prop_id)
     {
-    case PROP_MANAGER:
-      self->manager = g_value_dup_object (value);
+    case PROP_CONTEXT:
+      self->context = g_value_dup_object (value);
       break;
 
     case PROP_RELATIVE_TO:
@@ -678,11 +682,11 @@ gcal_month_popover_class_init (GcalMonthPopoverClass *klass)
   widget_class->show = gcal_month_popover_show;
   widget_class->realize = gcal_month_popover_realize;
 
-  properties [PROP_MANAGER] = g_param_spec_object ("manager",
-                                                   "Manager",
-                                                   "Manager",
-                                                   GCAL_TYPE_MANAGER,
-                                                   (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+  properties [PROP_CONTEXT] = g_param_spec_object ("context",
+                                                   "Context",
+                                                   "Context",
+                                                   GCAL_TYPE_CONTEXT,
+                                                   G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
   properties [PROP_RELATIVE_TO] = g_param_spec_object ("relative-to",
                                                        "Relative To",
@@ -877,10 +881,10 @@ gcal_month_popover_set_date (GcalMonthPopover *self,
 {
   g_return_if_fail (GCAL_IS_MONTH_POPOVER (self));
 
-  if (date && self->date && datetime_compare_date (self->date, date) == 0)
+  if (date && self->date && gcal_date_time_compare_date (self->date, date) == 0)
     return;
 
-  gcal_clear_datetime (&self->date);
+  gcal_clear_date_time (&self->date);
 
   if (date)
     {
